@@ -36,13 +36,19 @@ test_that("Synanthropic range data is downloaded", {
 
 test_that("Polygons are downloaded, not points", {
 
-  expect_in(
-    sf::st_geometry_type(cs_nat, by_geometry = FALSE) |> as.character(),
-    c("POLYGON", "MULTIPOLYGON")
-  )
+  if (inherits(cs_nat, "sf")) {
+    expect_in(
+      sf::st_geometry_type(cs_nat, by_geometry = FALSE) |> as.character(),
+      c("POLYGON", "MULTIPOLYGON")
+    )
+
+    expect_in(
+      sf::st_geometry_type(cs_syn, by_geometry = FALSE) |> as.character(),
+      c("POLYGON", "MULTIPOLYGON")
+    )
+  } else {
+    skip("Not a sf object, skipping test on atlas")
+  }
+
 
-  expect_in(
-    sf::st_geometry_type(cs_syn, by_geometry = FALSE) |> as.character(),
-    c("POLYGON", "MULTIPOLYGON")
-  )
 })
